cumulusci.tasks.github package
==============================

.. automodule:: cumulusci.tasks.github
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.tasks.github.base module
----------------------------------

.. automodule:: cumulusci.tasks.github.base
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.github.merge module
-----------------------------------

.. automodule:: cumulusci.tasks.github.merge
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.github.pull\_request module
-------------------------------------------

.. automodule:: cumulusci.tasks.github.pull_request
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.github.release module
-------------------------------------

.. automodule:: cumulusci.tasks.github.release
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.github.release\_report module
---------------------------------------------

.. automodule:: cumulusci.tasks.github.release_report
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.github.tag module
---------------------------------

.. automodule:: cumulusci.tasks.github.tag
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.github.util module
----------------------------------

.. automodule:: cumulusci.tasks.github.util
   :members:
   :undoc-members:
   :show-inheritance:

